@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2013-2022 -- leonerd@leonerd.org.uk
 
-package Devel::MAT 0.49;
+package Devel::MAT 0.50;
 
 use v5.14;
 use warnings;
@@ -341,6 +341,11 @@ sub inref_graph
       }->() } @inrefs;
    }
 
+   if( $sv->is_mortal ) {
+      $graph->add_root( $sv,
+         Devel::MAT::SV::Reference( "a mortal", strong => undef ) );
+   }
+
    foreach my $ref ( sort_by { $_->name } @inrefs ) {
       if( !defined $ref->sv ) {
          $graph->add_root( $sv, $ref );
